#!/usr/bin/env python

#  Copyright (C) 2008-2010 by Canonical Ltd
#  Copyright (C) 2012 Koichi Akabe <vbkaisetsu@gmail.com>
# 
#  gLogic is free software: you can redistribute it and/or modify it
#  under the terms of the GNU General Public License as published by the
#  Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
# 
#  gLogic is distributed in the hope that it will be useful, but
#  WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#  See the GNU General Public License for more details.
# 
#  You should have received a copy of the GNU General Public License along
#  with this program.  If not, see <http://www.gnu.org/licenses/>.
#

bzr_plugin_name = "tweet"

# dev or final
bzr_plugin_version = (1, 3, 0, "final", 0)

bzr_commands = ["tweet-auth", "tweet-branchid"]

bzr_compatible_versions = [(2, 5, 0), (2, 6, 0)]

bzr_minimum_version = bzr_compatible_versions[0]
bzr_maximum_version = bzr_compatible_versions[-1]

